package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TOtherSolve;

/**
 * 其他告警处理Mapper接口
 * 
 * @author zhengjie
 * @date 2023-09-09
 */
public interface TOtherSolveMapper 
{
    /**
     * 查询其他告警处理
     * 
     * @param id 其他告警处理主键
     * @return 其他告警处理
     */
    public TOtherSolve selectTOtherSolveById(Integer id);

    /**
     * 查询其他告警处理列表
     * 
     * @param tOtherSolve 其他告警处理
     * @return 其他告警处理集合
     */
    public List<TOtherSolve> selectTOtherSolveList(TOtherSolve tOtherSolve);

    /**
     * 新增其他告警处理
     * 
     * @param tOtherSolve 其他告警处理
     * @return 结果
     */
    public int insertTOtherSolve(TOtherSolve tOtherSolve);

    /**
     * 修改其他告警处理
     * 
     * @param tOtherSolve 其他告警处理
     * @return 结果
     */
    public int updateTOtherSolve(TOtherSolve tOtherSolve);

    /**
     * 删除其他告警处理
     * 
     * @param id 其他告警处理主键
     * @return 结果
     */
    public int deleteTOtherSolveById(Integer id);

    /**
     * 批量删除其他告警处理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTOtherSolveByIds(Integer[] ids);
}
