package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.THealthSolve;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TOtherSolve;
import com.ruoyi.system.service.ITOtherSolveService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 其他告警处理Controller
 * 
 * @author zhengjie
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/othersolve")
public class TOtherSolveController extends BaseController
{
    @Autowired
    private ITOtherSolveService tOtherSolveService;

    /**
     * 查询其他告警处理列表
     */
    @PreAuthorize("@ss.hasPermi('system:othersolve:list')")
    @GetMapping("/list")
    public TableDataInfo list(TOtherSolve tOtherSolve)
    {
        startPage();
        List<TOtherSolve> list = tOtherSolveService.selectTOtherSolveList(tOtherSolve);
        for (TOtherSolve salve : list){
            if (StringUtils.isNull(salve.getSolve_status())){
                salve.setSolve_status(0);
            }
            salve.setAlarmMsg("其他告警求助：" + salve.getName() + "于" + DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,salve.getCreatetime()) + "发起其他告警求助");
        }
        return getDataTable(list);
    }

    /**
     * 导出其他告警处理列表
     */
    @PreAuthorize("@ss.hasPermi('system:othersolve:export')")
    @Log(title = "其他告警处理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TOtherSolve tOtherSolve)
    {
        List<TOtherSolve> list = tOtherSolveService.selectTOtherSolveList(tOtherSolve);
        ExcelUtil<TOtherSolve> util = new ExcelUtil<TOtherSolve>(TOtherSolve.class);
        util.exportExcel(response, list, "其他告警处理数据");
    }

    /**
     * 获取其他告警处理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:othersolve:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tOtherSolveService.selectTOtherSolveById(id));
    }

    /**
     * 新增其他告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:othersolve:add')")
    @Log(title = "其他告警处理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TOtherSolve tOtherSolve)
    {
        return toAjax(tOtherSolveService.insertTOtherSolve(tOtherSolve));
    }

    /**
     * 修改其他告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:othersolve:edit')")
    @Log(title = "其他告警处理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TOtherSolve tOtherSolve)
    {
        return toAjax(tOtherSolveService.updateTOtherSolve(tOtherSolve));
    }

    /**
     * 删除其他告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:othersolve:remove')")
    @Log(title = "其他告警处理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tOtherSolveService.deleteTOtherSolveByIds(ids));
    }
}
